=== modified file 'lib/canonical/launchpad/browser/logintoken.py'
--- lib/canonical/launchpad/browser/logintoken.py	2011-02-02 15:43:31 +0000
+++ lib/canonical/launchpad/browser/logintoken.py	2011-02-16 17:31:11 +0000
@@ -572,6 +572,17 @@
         self.context.consume()
 
     def _doMerge(self):
+        """Merges a duplicate person into a target person.
+
+        - Reassigns the duplicate user's primary email address to the
+          requesting user.
+
+        - Ensures that the requesting user has a preferred email address, and
+          uses the newly acquired one if not.
+
+        - If the duplicate user has no other email addresses, does the merge.
+
+        """
         # The user proved that he has access to this email address of the
         # dupe account, so we can assign it to him.
         requester = self.context.requester

=== modified file 'lib/lp/registry/browser/peoplemerge.py'
--- lib/lp/registry/browser/peoplemerge.py	2011-01-07 15:16:52 +0000
+++ lib/lp/registry/browser/peoplemerge.py	2011-02-16 17:31:11 +0000
@@ -137,7 +137,11 @@
         self.dupe_person_emails = emailset.getByPerson(self.dupe_person)
 
     def doMerge(self, data):
-        """Merge the two person/team entries specified in the form."""
+        """Merge the two person/team entries specified in the form.
+
+        Before merging this moves each email address of the duplicate person
+        to the target person, and resets them to `NEW`.
+        """
         for email in self.dupe_person_emails:
             email = IMasterObject(email)
             # EmailAddress.person and EmailAddress.account are readonly
@@ -215,7 +219,21 @@
         return getUtility(ILaunchpadCelebrities).registry_experts
 
     def doMerge(self, data):
-        """Purge the non-transferable team data and merge."""
+        """Purge the non-transferable team data and merge.
+
+        For the duplicate team:
+
+        - If a mailing list exists, and is REGISTERED, DECLINED, FAILED or
+          INACTIVE, it is purged.
+
+        - Unsets the contact address.
+
+        If the target team is the Registry Experts:
+
+        - The duplicate team is withdrawn from all teams that it is itself a
+          member of.
+
+        """
         # A team cannot have more than one mailing list. The old list will
         # remain in the archive.
         purge_list = (self.dupe_person.mailing_list is not None

